@@ -1,18 +1,18 @@
 from kentik_api.api_calls import query_methods
 from kentik_api.api_resources.base_api import BaseAPI
 from kentik_api.requests_payload.queries_payload import QueryDataResponse, QueryChartResponse, QueryURLResponse
-from kentik_api.public.query_sql import SQLQuery, SQLQueryResult
+from kentik_api.public.query_sql import QuerySQL, QuerySQLResult
 from kentik_api.public.query_object import QueryObject, QueryDataResult, QueryChartResult, QueryURLResult
 
 
 class QueryAPI(BaseAPI):
     """Exposes Kentik API's Query API methods"""
 
-    def sql(self, query: SQLQuery) -> SQLQueryResult:
+    def sql(self, query: QuerySQL) -> QuerySQLResult:
         apicall = query_methods.query_sql()
         payload = query
         response = self.send(apicall, payload)
-        return SQLQueryResult.from_json(response.text)
+        return QuerySQLResult.from_json(response.text)
 
     def data(self, query: QueryObject) -> QueryDataResult:
         apicall = query_methods.query_data()
